# astromodels

[![Build Status](https://travis-ci.org/threeML/astromodels.svg?branch=master)](https://travis-ci.org/threeML/astromodels)
[![codecov](https://codecov.io/gh/giacomov/astromodels/branch/master/graph/badge.svg)](https://codecov.io/gh/giacomov/astromodels)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)

Spatial and spectral models for astrophysics

Documentation: http://astromodels.readthedocs.org/en/latest/
